/* RGBled_pwm
 * Egy RGB LED színeit keverjük három potméter segítségével,
 * az analogRead() és az analogWrite() függvény használatával.
 * 
 * Kapcsolás:
 * - Kössük három potméter csúszkáját az A0,A1,A2 bemenetekre 
 *   (a potméterek két végét pedig GND és +5V közé)!
 * - Kössük egy RGB LED közös elektródáját a D4 kimenetre, 
 *   a többi kivezetését pedig egy-egy 470 ohmos áramkorlátozó 
 *   ellenálláson keresztül a D3, D5 és D6 kimenetekre!
 *   
 *   Igazítsuk a programot a LED-hez:
 *   - Közös katódú LED esetén common_level = LOW legyen!
 *   - Közös anódú LED esetén commonlevel = HIGH legyen!
 *                   ___________
 *                  |           |      470R
 *         |--------| A0     D3 |-----/\/\/\--- RED     
 * +5V -/\/\/\- GND |           |                       L
 *       10K        |        D4 |-------------- Common
 *                  |           |     470R              E
 *         |--------| A1     D5 |-----/\/\/\--- GREEN 
 * +5V -/\/\/\- GND |           |                       D
 *       10K        |        D6 |-----/\/\/\--- BLUE      
 *         |--------| A2        |
 * +5V -/\/\/\- GND |  Arduino  |       
 *       10K        |___________| 
 *     
 */
#define red    3          // Piros LED = D3
#define common 4          // Közös elektróda = D4
#define green  5          // Zöld LED = D5
#define blue   6          // Kék LED = D6
#define common_level HIGH // Közös elektróda(LOW: katód, HIGH: anód)
byte r = 0, g = 0, b=0;
int t = 25;

void setup() {
  pinMode(common,OUTPUT);
  setRGB();
}

void loop() {
  r = analogRead(A0)>>2;
  g = analogRead(A1)>>2;
  b = analogRead(A2)>>2;
  setRGB();
}

void setRGB(void) {
  if (common_level == HIGH) {
    digitalWrite(common, HIGH);
    analogWrite(red,255-r);
    analogWrite(green, 255-g);
    analogWrite(blue, 255-b);    
  }
  else {
    digitalWrite(common, LOW);
    analogWrite(red,r);
    analogWrite(green, g);
    analogWrite(blue, b);     
  }
  delay(t);
}
